/********************************************************************************
** Form generated from reading UI file 'customgame.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMGAME_H
#define UI_CUSTOMGAME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kpluralhandlingspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_CustomGameConfig
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem;
    QLabel *width;
    QSpacerItem *spacerItem1;
    KPluralHandlingSpinBox *kcfg_Width;
    QCheckBox *kcfg_Wrapping;
    QLabel *height;
    KPluralHandlingSpinBox *kcfg_Height;

    void setupUi(QWidget *CustomGameConfig)
    {
        if (CustomGameConfig->objectName().isEmpty())
            CustomGameConfig->setObjectName("CustomGameConfig");
        CustomGameConfig->resize(316, 241);
        gridLayout = new QGridLayout(CustomGameConfig);
        gridLayout->setObjectName("gridLayout");
        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 3, 1, 1, 1);

        width = new QLabel(CustomGameConfig);
        width->setObjectName("width");

        gridLayout->addWidget(width, 0, 0, 1, 1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem1, 0, 2, 1, 1);

        kcfg_Width = new KPluralHandlingSpinBox(CustomGameConfig);
        kcfg_Width->setObjectName("kcfg_Width");

        gridLayout->addWidget(kcfg_Width, 0, 1, 1, 1);

        kcfg_Wrapping = new QCheckBox(CustomGameConfig);
        kcfg_Wrapping->setObjectName("kcfg_Wrapping");

        gridLayout->addWidget(kcfg_Wrapping, 2, 0, 1, 2);

        height = new QLabel(CustomGameConfig);
        height->setObjectName("height");

        gridLayout->addWidget(height, 1, 0, 1, 1);

        kcfg_Height = new KPluralHandlingSpinBox(CustomGameConfig);
        kcfg_Height->setObjectName("kcfg_Height");

        gridLayout->addWidget(kcfg_Height, 1, 1, 1, 1);


        retranslateUi(CustomGameConfig);

        QMetaObject::connectSlotsByName(CustomGameConfig);
    } // setupUi

    void retranslateUi(QWidget *CustomGameConfig)
    {
#if QT_CONFIG(tooltip)
        width->setToolTip(tr2i18n("Width of the grid", nullptr));
#endif // QT_CONFIG(tooltip)
        width->setText(tr2i18n("Width:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_Wrapping->setToolTip(tr2i18n("Wrap from left to right and from top to bottom", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_Wrapping->setText(tr2i18n("Wrapping", nullptr));
#if QT_CONFIG(tooltip)
        height->setToolTip(tr2i18n("Height of the grid", nullptr));
#endif // QT_CONFIG(tooltip)
        height->setText(tr2i18n("Height:", nullptr));
        (void)CustomGameConfig;
    } // retranslateUi

};

namespace Ui {
    class CustomGameConfig: public Ui_CustomGameConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUSTOMGAME_H

