/********************************************************************************
** Form generated from reading UI file 'general.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERAL_H
#define UI_GENERAL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kpluralhandlingspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_GeneralConfig
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QSpacerItem *spacerItem;
    QCheckBox *kcfg_PlaySounds;
    KPluralHandlingSpinBox *kcfg_RotateDuration;
    QCheckBox *kcfg_Autolock;
    QSpacerItem *spacerItem1;
    QCheckBox *kcfg_ReverseButtons;

    void setupUi(QWidget *GeneralConfig)
    {
        if (GeneralConfig->objectName().isEmpty())
            GeneralConfig->setObjectName("GeneralConfig");
        GeneralConfig->resize(316, 241);
        gridLayout = new QGridLayout(GeneralConfig);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(GeneralConfig);
        label->setObjectName("label");

        gridLayout->addWidget(label, 3, 1, 1, 1);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 4, 1, 1, 1);

        kcfg_PlaySounds = new QCheckBox(GeneralConfig);
        kcfg_PlaySounds->setObjectName("kcfg_PlaySounds");

        gridLayout->addWidget(kcfg_PlaySounds, 0, 1, 1, 1);

        kcfg_RotateDuration = new KPluralHandlingSpinBox(GeneralConfig);
        kcfg_RotateDuration->setObjectName("kcfg_RotateDuration");
        kcfg_RotateDuration->setSingleStep(100);

        gridLayout->addWidget(kcfg_RotateDuration, 3, 2, 1, 1);

        kcfg_Autolock = new QCheckBox(GeneralConfig);
        kcfg_Autolock->setObjectName("kcfg_Autolock");

        gridLayout->addWidget(kcfg_Autolock, 1, 1, 1, 1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem1, 0, 3, 1, 1);

        kcfg_ReverseButtons = new QCheckBox(GeneralConfig);
        kcfg_ReverseButtons->setObjectName("kcfg_ReverseButtons");

        gridLayout->addWidget(kcfg_ReverseButtons, 2, 1, 1, 1);


        retranslateUi(GeneralConfig);

        QMetaObject::connectSlotsByName(GeneralConfig);
    } // setupUi

    void retranslateUi(QWidget *GeneralConfig)
    {
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("Duration for cell to complete one rotation in milliseconds", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Rotate duration:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_PlaySounds->setToolTip(tr2i18n("Play sounds on actions", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_PlaySounds->setText(tr2i18n("Play sounds", nullptr));
        kcfg_RotateDuration->setSpecialValueText(QString());
#if QT_CONFIG(tooltip)
        kcfg_Autolock->setToolTip(tr2i18n("Automatically lock cell after rotation", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_Autolock->setText(tr2i18n("Auto lock", nullptr));
        kcfg_ReverseButtons->setText(tr2i18n("Reverse mouse buttons", nullptr));
        (void)GeneralConfig;
    } // retranslateUi

};

namespace Ui {
    class GeneralConfig: public Ui_GeneralConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERAL_H

